@@ -18,6 +18,18 @@ TableHelper.reserved = reserved_words
 TableHelper.operators = OPERATORS
 
 
+system_fields = [
+    "sys_id",
+    "sys_created",
+    "sys_modified",
+    "sys_modified_by",
+    "sys_dirty",
+    "sys_table",
+    "sys_modified_count",
+    "description",
+]
+
+
 def quote(data):
     """Quote SQLite identifiers."""
     if isinstance(data, list):
@@ -344,11 +356,122 @@ class SQL(BaseSQLDialect):
 
     @classmethod
     def create_table(cls, name, columns=None, drop=False):
+        if not name or not isinstance(name, str):
+            raise ValueError("Table name must be a non-empty string")
+
+        columns = columns or {}
+        table_identifier = quote(name)
+        base_name = name.split(".")[-1].replace('"', "")
+        base_name_sql = base_name.replace("'", "''")
+        trigger_prefix = re.sub(r"[^0-9A-Za-z_]+", "_", f"cc_sysmod_{base_name}")
+
+        statements = []
         if drop:
-            return f"DROP TABLE IF EXISTS {quote(name)}"
-        
-        # Basic CREATE TABLE
-        return f"CREATE TABLE {quote(name)} (id INTEGER PRIMARY KEY AUTOINCREMENT)"
+            statements.append(f"DROP TABLE IF EXISTS {table_identifier};")
+
+        statements.append(
+            f"""
+CREATE TABLE {table_identifier} (
+  "sys_id" INTEGER PRIMARY KEY AUTOINCREMENT,
+  "sys_table" TEXT,
+  "sys_created" TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
+  "sys_modified" TEXT NOT NULL DEFAULT CURRENT_TIMESTAMP,
+  "sys_modified_by" TEXT,
+  "sys_modified_count" INTEGER NOT NULL DEFAULT 0,
+  "sys_dirty" INTEGER NOT NULL DEFAULT 0,
+  "description" TEXT
+);
+""".strip()
+        )
+
+        for key, val in columns.items():
+            clean_key = re.sub("<>!=%", "", key)
+            if clean_key in system_fields:
+                continue
+            col_type = TYPES.get_type(val)
+            statements.append(
+                f"ALTER TABLE {table_identifier} ADD COLUMN {quote(clean_key)} {col_type};"
+            )
+
+        statements.extend(
+            [
+                f"DROP TRIGGER IF EXISTS {trigger_prefix}_ai;",
+                f"DROP TRIGGER IF EXISTS {trigger_prefix}_au;",
+                f"""
+CREATE TRIGGER {trigger_prefix}_ai
+AFTER INSERT ON {table_identifier}
+FOR EACH ROW
+BEGIN
+    UPDATE {table_identifier}
+    SET sys_created = COALESCE(NEW.sys_created, CURRENT_TIMESTAMP),
+        sys_modified = CURRENT_TIMESTAMP,
+        sys_modified_count = 0,
+        sys_dirty = COALESCE(NEW.sys_dirty, 0),
+        sys_table = '{base_name_sql}'
+    WHERE rowid = NEW.rowid;
+END;
+""".strip(),
+                f"""
+CREATE TRIGGER {trigger_prefix}_au
+AFTER UPDATE ON {table_identifier}
+FOR EACH ROW
+BEGIN
+    UPDATE {table_identifier}
+    SET sys_created = OLD.sys_created,
+        sys_modified = CURRENT_TIMESTAMP,
+        sys_table = '{base_name_sql}',
+        sys_dirty = CASE WHEN OLD.sys_dirty = 1 AND NEW.sys_dirty = 0 THEN 0 ELSE 1 END,
+        sys_modified_count = CASE WHEN OLD.sys_dirty = 1 AND NEW.sys_dirty = 0 THEN COALESCE(OLD.sys_modified_count, 0) ELSE COALESCE(OLD.sys_modified_count, 0) + 1 END
+    WHERE rowid = NEW.rowid;
+END;
+""".strip(),
+            ]
+        )
+
+        return "\n".join(statements), tuple()
+
+    @classmethod
+    def ensure_sys_modified_count(cls, name):
+        """Ensure sys_modified_count exists for SQLite tables."""
+        table_identifier = quote(name)
+        base_name = name.split(".")[-1].replace('"', "")
+        base_name_sql = base_name.replace("'", "''")
+        trigger_prefix = re.sub(r"[^0-9A-Za-z_]+", "_", f"cc_sysmod_{base_name}")
+        statements = [
+            f"ALTER TABLE {table_identifier} ADD COLUMN sys_modified_count INTEGER NOT NULL DEFAULT 0;",
+            f"UPDATE {table_identifier} SET sys_modified_count = 0 WHERE sys_modified_count IS NULL;",
+            f"DROP TRIGGER IF EXISTS {trigger_prefix}_ai;",
+            f"DROP TRIGGER IF EXISTS {trigger_prefix}_au;",
+            f"""
+CREATE TRIGGER {trigger_prefix}_ai
+AFTER INSERT ON {table_identifier}
+FOR EACH ROW
+BEGIN
+    UPDATE {table_identifier}
+    SET sys_created = COALESCE(NEW.sys_created, CURRENT_TIMESTAMP),
+        sys_modified = CURRENT_TIMESTAMP,
+        sys_modified_count = 0,
+        sys_dirty = COALESCE(NEW.sys_dirty, 0),
+        sys_table = '{base_name_sql}'
+    WHERE rowid = NEW.rowid;
+END;
+""".strip(),
+            f"""
+CREATE TRIGGER {trigger_prefix}_au
+AFTER UPDATE ON {table_identifier}
+FOR EACH ROW
+BEGIN
+    UPDATE {table_identifier}
+    SET sys_created = OLD.sys_created,
+        sys_modified = CURRENT_TIMESTAMP,
+        sys_table = '{base_name_sql}',
+        sys_dirty = CASE WHEN OLD.sys_dirty = 1 AND NEW.sys_dirty = 0 THEN 0 ELSE 1 END,
+        sys_modified_count = CASE WHEN OLD.sys_dirty = 1 AND NEW.sys_dirty = 0 THEN COALESCE(OLD.sys_modified_count, 0) ELSE COALESCE(OLD.sys_modified_count, 0) + 1 END
+    WHERE rowid = NEW.rowid;
+END;
+""".strip(),
+        ]
+        return "\n".join(statements), tuple()
 
     @classmethod
     def drop_table(cls, name):
