@@ -18,6 +18,18 @@ TableHelper.reserved = reserved_words
 TableHelper.operators = OPERATORS
 
 
+system_fields = [
+    "sys_id",
+    "sys_created",
+    "sys_modified",
+    "sys_modified_by",
+    "sys_dirty",
+    "sys_table",
+    "sys_modified_count",
+    "description",
+]
+
+
 def quote(data):
     """Quote SQL Server identifiers."""
     if isinstance(data, list):
@@ -383,11 +395,158 @@ class SQL(BaseSQLDialect):
 
     @classmethod
     def create_table(cls, name, columns=None, drop=False):
+        if not name or not isinstance(name, str):
+            raise ValueError("Table name must be a non-empty string")
+
+        columns = columns or {}
+
+        if "." in name:
+            schema_part, table_part = name.split(".", 1)
+        else:
+            schema_part = cls.default_schema or "dbo"
+            table_part = name
+
+        schema_identifier = quote(schema_part)
+        table_identifier = quote(name if "." in name else f"{schema_part}.{table_part}")
+        base_name = table_part.replace("[", "").replace("]", "")
+        base_name_sql = base_name.replace("'", "''")
+        trigger_prefix = re.sub(r"[^0-9A-Za-z_]+", "_", f"CC_SYS_MOD_{base_name}")
+
+        statements = []
         if drop:
-            return f"DROP TABLE IF EXISTS {quote(name)}"
-        
-        # Basic CREATE TABLE
-        return f"CREATE TABLE {quote(name)} (id INT IDENTITY(1,1) PRIMARY KEY)"
+            statements.append(f"IF OBJECT_ID(N'{table_identifier}', N'U') IS NOT NULL DROP TABLE {table_identifier};")
+
+        statements.append(
+            f"""
+CREATE TABLE {table_identifier} (
+  [sys_id] BIGINT IDENTITY(1,1) PRIMARY KEY,
+  [sys_table] NVARCHAR(255),
+  [sys_created] DATETIME2 NOT NULL DEFAULT SYSDATETIME(),
+  [sys_modified] DATETIME2 NOT NULL DEFAULT SYSDATETIME(),
+  [sys_modified_by] NVARCHAR(255),
+  [sys_modified_count] INT NOT NULL DEFAULT 0,
+  [sys_dirty] BIT NOT NULL DEFAULT 0,
+  [description] NVARCHAR(MAX)
+);
+""".strip()
+        )
+
+        for key, val in columns.items():
+            clean_key = re.sub("<>!=%", "", key)
+            if clean_key in system_fields:
+                continue
+            col_type = TYPES.get_type(val)
+            statements.append(
+                f"ALTER TABLE {table_identifier} ADD {quote(clean_key)} {col_type};"
+            )
+
+        statements.extend(
+            [
+                f"IF OBJECT_ID(N'{schema_identifier}.{trigger_prefix}_insert', N'TR') IS NOT NULL DROP TRIGGER {schema_identifier}.{trigger_prefix}_insert;",
+                f"IF OBJECT_ID(N'{schema_identifier}.{trigger_prefix}_update', N'TR') IS NOT NULL DROP TRIGGER {schema_identifier}.{trigger_prefix}_update;",
+                f"""
+CREATE TRIGGER {schema_identifier}.{trigger_prefix}_insert
+ON {table_identifier}
+AFTER INSERT
+AS
+BEGIN
+    SET NOCOUNT ON;
+    UPDATE t
+    SET sys_created = ISNULL(i.sys_created, SYSDATETIME()),
+        sys_modified = SYSDATETIME(),
+        sys_modified_count = 0,
+        sys_dirty = ISNULL(i.sys_dirty, 0),
+        sys_table = '{base_name_sql}'
+    FROM {table_identifier} AS t
+    INNER JOIN inserted AS i ON t.sys_id = i.sys_id;
+END;
+""".strip(),
+                f"""
+CREATE TRIGGER {schema_identifier}.{trigger_prefix}_update
+ON {table_identifier}
+AFTER UPDATE
+AS
+BEGIN
+    SET NOCOUNT ON;
+    UPDATE t
+    SET sys_created = d.sys_created,
+        sys_modified = SYSDATETIME(),
+        sys_table = '{base_name_sql}',
+        sys_dirty = CASE WHEN d.sys_dirty = 1 AND i.sys_dirty = 0 THEN 0 ELSE 1 END,
+        sys_modified_count = CASE WHEN d.sys_dirty = 1 AND i.sys_dirty = 0 THEN ISNULL(d.sys_modified_count, 0) ELSE ISNULL(d.sys_modified_count, 0) + 1 END
+    FROM {table_identifier} AS t
+    INNER JOIN inserted AS i ON t.sys_id = i.sys_id
+    INNER JOIN deleted AS d ON d.sys_id = i.sys_id;
+END;
+""".strip(),
+            ]
+        )
+
+        return "\n".join(statements), tuple()
+
+    @classmethod
+    def ensure_sys_modified_count(cls, name, has_column=False):
+        """Ensure sys_modified_count exists for SQL Server tables along with maintenance triggers."""
+        if "." in name:
+            schema, table_name = name.split(".", 1)
+        else:
+            schema = cls.default_schema or "dbo"
+            table_name = name
+
+        schema_identifier = quote(schema)
+        table_identifier = quote(name if "." in name else f"{schema}.{table_name}")
+        object_name = f"[{schema}].[{table_name}]"
+        table_name_sql = table_name.replace("'", "''")
+        trigger_prefix = re.sub(r"[^0-9A-Za-z_]+", "_", f"CC_SYS_MOD_{table_name}")
+
+        statements = []
+        if not has_column:
+            statements.append(
+                f"IF COL_LENGTH(N'{object_name}', 'sys_modified_count') IS NULL BEGIN ALTER TABLE {table_identifier} ADD sys_modified_count INT NOT NULL CONSTRAINT DF_{trigger_prefix}_COUNT DEFAULT (0); END;"
+            )
+
+        statements.extend([
+            f"UPDATE {table_identifier} SET sys_modified_count = 0 WHERE sys_modified_count IS NULL;",
+            f"IF OBJECT_ID(N'{schema_identifier}.{trigger_prefix}_insert', N'TR') IS NOT NULL DROP TRIGGER {schema_identifier}.{trigger_prefix}_insert;",
+            f"IF OBJECT_ID(N'{schema_identifier}.{trigger_prefix}_update', N'TR') IS NOT NULL DROP TRIGGER {schema_identifier}.{trigger_prefix}_update;",
+            f"""
+CREATE TRIGGER {schema_identifier}.{trigger_prefix}_insert
+ON {table_identifier}
+AFTER INSERT
+AS
+BEGIN
+    SET NOCOUNT ON;
+    UPDATE t
+    SET sys_created = ISNULL(i.sys_created, SYSDATETIME()),
+        sys_modified = SYSDATETIME(),
+        sys_modified_count = 0,
+        sys_dirty = ISNULL(i.sys_dirty, 0),
+        sys_table = '{table_name_sql}'
+    FROM {table_identifier} AS t
+    INNER JOIN inserted AS i ON t.sys_id = i.sys_id;
+END;
+""".strip(),
+            f"""
+CREATE TRIGGER {schema_identifier}.{trigger_prefix}_update
+ON {table_identifier}
+AFTER UPDATE
+AS
+BEGIN
+    SET NOCOUNT ON;
+    UPDATE t
+    SET sys_created = d.sys_created,
+        sys_modified = SYSDATETIME(),
+        sys_table = '{table_name_sql}',
+        sys_dirty = CASE WHEN d.sys_dirty = 1 AND i.sys_dirty = 0 THEN 0 ELSE 1 END,
+        sys_modified_count = CASE WHEN d.sys_dirty = 1 AND i.sys_dirty = 0 THEN ISNULL(d.sys_modified_count, 0) ELSE ISNULL(d.sys_modified_count, 0) + 1 END
+    FROM {table_identifier} AS t
+    INNER JOIN inserted AS i ON t.sys_id = i.sys_id
+    INNER JOIN deleted AS d ON d.sys_id = i.sys_id;
+END;
+""".strip(),
+        ])
+
+        return "\n".join(statements), tuple()
 
     @classmethod
     def drop_table(cls, name):
