@@ -5,7 +5,7 @@ This module provides utility functions to handle common database operations
 safely, including sorting with None values and other edge cases.
 """
 
-from typing import Any, Callable, List, Optional, Union
+from typing import Any, Callable, List
 
 
 def safe_sort_key_none_last(field_name: str) -> Callable[[dict], tuple]:
